tlslite.integration.HTTPTLSConnection.HTTPBaseTLSConnection

Package tlslite :: Package integration :: Module HTTPTLSConnection :: Class HTTPBaseTLSConnection |
[show private | hide private]
[frames | no frames]

## Class HTTPBaseTLSConnection

    HTTPConnection --+
                     |
                    HTTPBaseTLSConnection

Known Subclasses:
  `HTTPTLSConnection`

This abstract class provides a framework for adding TLS support to httplib.

Method Summary
| `__init__(self, host, port, strict)`
| ``connect`(self)` Connect to the host and port specified in __init__.
Inherited from HTTPConnection
| ``close`(self)` Close the connection to the HTTP server.
| ``endheaders`(self)` Indicate that the last header line has been sent to the server.
| ``getresponse`(self)` Get the response from the server.
| ``putheader`(self, header, value)` Send a request header line to the server.
| ``putrequest`(self, method, url, skip_host)` Send a request to the server.
| ``request`(self, method, url, body, headers)` Send a complete request to the server.
| ``send`(self, str)` Send `str' to the server.
| ``set_debuglevel`(self, level)`

Class Variable Summary
`int` | `default_port` = 443
Inherited from HTTPConnection
`int` | `auto_open` = 1
`int` | `debuglevel` = 0
`int` | `strict` = 0

Method Details

### connect(self) Connect to the host and port specified in __init__. Overrides: `httplib.HTTPConnection.connect` (inherited documentation)

Class Variable Details

    ### default_port Type: `int` Value:
        443

Generated by Epydoc 2.0 on Mon Feb 21 21:56:54 2005 | http://epydoc.sf.net